@@ -20,7 +20,7 @@ def resolve(project, repository):
     ):
         repository.environment.python_requires = PySpecSet(requires_python)
         if allow_prereleases is not None:
-            project.tool_settings["allow_prereleases"] = allow_prereleases
+            project.pyproject.settings["allow_prereleases"] = allow_prereleases
         requirements = []
         for line in lines:
             if line.startswith("-e "):
@@ -97,6 +97,7 @@ def test_resolve_with_extras(resolve):
         f"{(FIXTURES / 'artifacts/demo-0.0.1.tar.gz').as_posix()}",
         f"{(FIXTURES / 'artifacts/demo-0.0.1-py2.py3-none-any.whl').as_posix()}",
     ],
+    ids=["sdist", "wheel"],
 )
 def test_resolve_local_artifacts(resolve, requirement_line):
     result = resolve([requirement_line], ">=3.6")
@@ -169,7 +170,7 @@ def test_resolve_conflicting_dependencies_with_overrides(
     repository.add_dependencies("bar", "0.1.0", ["hoho~=1.1"])
     repository.add_candidate("hoho", "2.1")
     repository.add_candidate("hoho", "1.5")
-    project.tool_settings["overrides"] = {"hoho": overrides}
+    project.pyproject.settings["resolution"] = {"overrides": {"hoho": overrides}}
     result = resolve(["foo", "bar"])
     assert result["hoho"].version == "2.1"
 
@@ -238,32 +239,34 @@ def test_resolve_circular_dependencies(resolve, repository):
 
 
 def test_resolve_candidates_to_install(project):
-    project.lockfile = {
-        "package": [
-            {
-                "name": "pytest",
-                "version": "4.6.0",
-                "summary": "pytest module",
-                "dependencies": ["py>=3.0", "configparser; sys_platform=='win32'"],
-            },
-            {
-                "name": "configparser",
-                "version": "1.2.0",
-                "summary": "configparser module",
-                "dependencies": ["backports"],
-            },
-            {
-                "name": "py",
-                "version": "3.6.0",
-                "summary": "py module",
-            },
-            {
-                "name": "backports",
-                "version": "2.2.0",
-                "summary": "backports module",
-            },
-        ]
-    }
+    project.lockfile.set_data(
+        {
+            "package": [
+                {
+                    "name": "pytest",
+                    "version": "4.6.0",
+                    "summary": "pytest module",
+                    "dependencies": ["py>=3.0", "configparser; sys_platform=='win32'"],
+                },
+                {
+                    "name": "configparser",
+                    "version": "1.2.0",
+                    "summary": "configparser module",
+                    "dependencies": ["backports"],
+                },
+                {
+                    "name": "py",
+                    "version": "3.6.0",
+                    "summary": "py module",
+                },
+                {
+                    "name": "backports",
+                    "version": "2.2.0",
+                    "summary": "backports module",
+                },
+            ]
+        }
+    )
     project.environment.marker_environment["sys_platform"] = "linux"
     reqs = [parse_requirement("pytest")]
     result = resolve_candidates_from_lockfile(project, reqs)
@@ -310,3 +313,14 @@ def test_resolve_extra_requirements_no_break_constraints(resolve, repository):
     result = resolve(["foo[chardet]<0.2.0"])
     assert "chardet" in result
     assert result["foo"].version == "0.1.0"
+
+
+def test_resolve_extra_and_underlying_to_the_same_version(resolve, repository):
+    repository.add_candidate("foo", "0.1.0")
+    repository.add_dependencies("foo", "0.1.0", ["chardet; extra=='enc'"])
+    repository.add_candidate("foo", "0.2.0")
+    repository.add_dependencies("foo", "0.2.0", ["chardet; extra=='enc'"])
+    repository.add_candidate("bar", "0.1.0")
+    repository.add_dependencies("bar", "0.1.0", ["foo[enc]>=0.1.0"])
+    result = resolve(["foo==0.1.0", "bar"])
+    assert result["foo"].version == result["foo[enc]"].version == "0.1.0"
