@@ -1,6 +1,8 @@
+import shutil
 from argparse import Namespace
 
-from pdm.formats import flit, legacy, pipfile, poetry, requirements, setup_py
+from pdm.formats import flit, pipfile, poetry, requirements, setup_py
+from pdm.models.requirements import parse_requirement
 from pdm.utils import cd
 from tests import FIXTURES
 
@@ -32,6 +34,10 @@ def test_convert_requirements_file(project, is_dev):
     assert "webassets==2.0" in group
     assert 'whoosh==2.7.4; sys_platform == "win32"' in group
     assert "-e git+https://github.com/pypa/pip.git@main#egg=pip" in group
+    assert (
+        "pep508-package @ git+https://github.com/techalchemy/test-project.git"
+        "@master#subdirectory=parent_folder/pep508-package" in group
+    )
 
 
 def test_convert_requirements_file_without_name(project, vcs):
@@ -44,11 +50,11 @@ def test_convert_requirements_file_without_name(project, vcs):
         project, str(req_file), Namespace(dev=False, group=None)
     )
 
-    assert result["dependencies"] == ["demo@ git+https://github.com/test-root/demo.git"]
+    assert result["dependencies"] == ["git+https://github.com/test-root/demo.git"]
 
 
 def test_convert_poetry(project):
-    golden_file = FIXTURES / "pyproject-poetry.toml"
+    golden_file = FIXTURES / "pyproject.toml"
     assert poetry.check_fingerprint(project, golden_file)
     with cd(FIXTURES):
         result, settings = poetry.convert(
@@ -61,7 +67,7 @@ def test_convert_poetry(project):
     }
     assert result["name"] == "poetry"
     assert result["version"] == "1.0.0"
-    assert result["license-expression"] == "MIT"
+    assert result["license"] == {"text": "MIT"}
     assert "repository" in result["urls"]
     assert result["requires-python"] == ">=2.7,<4.0,!=3.0.*,!=3.1.*,!=3.2.*,!=3.3.*"
     assert 'cleo<1.0.0,>=0.7.6; python_version ~= "2.7"' in result["dependencies"]
@@ -78,8 +84,9 @@ def test_convert_poetry(project):
     assert result["entry-points"]["blogtool.parsers"] == {
         ".rst": "some_module:SomeClass"
     }
-    assert settings["includes"] == ["lib/my_package", "tests", "CHANGELOG.md"]
-    assert settings["excludes"] == ["my_package/excluded.py"]
+    build = settings["build"]
+    assert build["includes"] == ["lib/my_package", "tests", "CHANGELOG.md"]
+    assert build["excludes"] == ["my_package/excluded.py"]
 
 
 def test_convert_flit(project):
@@ -114,29 +121,9 @@ def test_convert_flit(project):
         result["entry-points"]["pygments.lexers"]["dogelang"]
         == "dogelang.lexer:DogeLexer"
     )
-    assert settings["includes"] == ["doc/"]
-    assert settings["excludes"] == ["doc/*.html"]
-
-
-def test_convert_legacy_format(project):
-    golden_file = FIXTURES / "pyproject-legacy.toml"
-    assert legacy.check_fingerprint(project, golden_file)
-    result, settings = legacy.convert(project, golden_file, None)
-
-    assert result["name"] == "demo-package"
-    assert result["authors"][0] == {"name": "frostming", "email": "mianghong@gmail.com"}
-    assert result["license-expression"] == "MIT"
-    assert sorted(result["dynamic"]) == ["classifiers", "version"]
-    assert result["dependencies"] == ["flask"]
-    assert not result.get("dev-dependencies", {}).get("dev")
-    assert result["optional-dependencies"]["test"] == ["pytest"]
-    assert settings["source"][0]["url"] == "https://test.pypi.org/simple"
-
-
-def test_export_setup_py(fixture_project):
-    project = fixture_project("demo-package")
-    content = setup_py.export(project, [], None)
-    assert content == project.root.joinpath("setup.txt").read_text()
+    build = settings["build"]
+    assert build["includes"] == ["doc/"]
+    assert build["excludes"] == ["doc/*.html"]
 
 
 def test_import_requirements_with_group(project):
@@ -157,12 +144,40 @@ def test_import_requirements_with_group(project):
 def test_export_expand_env_vars_in_source(project, monkeypatch):
     monkeypatch.setenv("USER", "foo")
     monkeypatch.setenv("PASSWORD", "bar")
-    project.tool_settings["source"] = [
+    project.pyproject.settings["source"] = [
         {"url": "https://${USER}:${PASSWORD}@test.pypi.org/simple", "name": "pypi"}
     ]
-    project.write_pyproject()
-    result = requirements.export(project, [], None)
+    result = requirements.export(project, [], Namespace())
     assert (
         result.strip().splitlines()[-1]
         == "--index-url https://foo:bar@test.pypi.org/simple"
     )
+
+
+def test_export_replace_project_root(project):
+    artifact = FIXTURES / "artifacts/first-2.0.2-py2.py3-none-any.whl"
+    shutil.copy2(artifact, project.root)
+    with cd(project.root):
+        req = parse_requirement(f"./{artifact.name}")
+    result = requirements.export(project, [req], Namespace(hashes=False))
+    assert "${PROJECT_ROOT}" not in result
+
+
+def test_convert_setup_py_project(project):
+    golden_file = FIXTURES / "projects/test-setuptools/setup.py"
+    assert setup_py.check_fingerprint(project, golden_file)
+    result, settings = setup_py.convert(project, golden_file, Namespace())
+    assert result == {
+        "name": "mymodule",
+        "version": "0.1.0",
+        "description": "A test module",
+        "keywords": ["one", "two"],
+        "readme": "README.md",
+        "authors": [{"name": "frostming"}],
+        "license": {"text": "MIT"},
+        "classifiers": ["Framework :: Django", "Programming Language :: Python :: 3"],
+        "requires-python": ">=3.5",
+        "dependencies": ['importlib-metadata; python_version<"3.8"', "requests"],
+        "scripts": {"mycli": "mymodule:main"},
+    }
+    assert settings == {"package-dir": "src"}
